@@ -51,7 +51,11 @@ as.zoo.timeSeries <- function(x, ...) {
 }
 
 as.zoo.xts <- function(x, ...) {
-  zoo(coredata(x), order.by = index(x), ...)
+  y <- coredata(x)
+  if (length(y) == 0) {
+    y <- NULL
+  }
+  zoo(y, order.by = index(x), ...)
 }
 
 as.zooreg.xts <- function(x, frequency = NULL, ...) {
@@ -86,7 +90,7 @@ as.matrix.zoo <- function(x, ...)
 
 as.data.frame.zoo <- function(x, row.names = NULL, optional = FALSE, ...)
 {
-	y <- as.data.frame(coredata(x), optional = optional)
+	y <- as.data.frame(coredata(x), optional = optional, ...)
         if(NCOL(x) > 0 && !optional) {
 		colnames(y) <- if (length(colnames(x)) > 0) 
 			colnames(x)
