@@ -24,7 +24,7 @@ zoo <- function (x = NULL, order.by = index(x), frequency = NULL,
 
     if(!is.null(frequency)) {
       delta <- suppressWarnings(try(diff(as.numeric(order.by)), silent = TRUE))
-      freqOK <- if(class(delta) == "try-error" || any(is.na(delta))) FALSE
+      freqOK <- if(inherits(delta, "try-error") || anyNA(delta)) FALSE
         else if(length(delta) < 1) TRUE
         else identical(all.equal(delta*frequency, round(delta*frequency)), TRUE)
       if(!freqOK) {
@@ -84,7 +84,7 @@ print.zoo <- function (x, style = ifelse(length(dim(x)) == 0,
 
 summary.zoo <- function(object, ...) 
 {
-	y <- as.data.frame(object)
+	y <- as.data.frame(object, row.names = NULL)
 	if (length(colnames(object)) < 1) {
 		lab <- deparse(substitute(object))
 		colnames(y) <- if (NCOL(object) == 1) lab
@@ -232,13 +232,13 @@ str.zoo <- function(object, ...)
     return(setNames(merge(object, value, drop = FALSE), x))
   }
   if(length(dim(object)) != 2) stop("not possible for univariate zoo series")
-  if(NCOL(object) > 0L & is.null(colnames(object))) stop("only possible for zoo series with column names")
-  wi <- match(x, colnames(object))
+  if(NCOL(object) > 0L && is.null(cnam <- colnames(object))) stop("only possible for zoo series with column names")
+  wi <- match(x, cnam)
   if(is.na(wi)) {
     if(!is.null(value)) {
       object <- cbind(object, value)
       if(is.null(dim(object))) dim(object) <- c(length(object), 1)
-      colnames(object)[NCOL(object)] <- x  
+      if(!identical(colnames(object), cnam)) colnames(object)[NCOL(object)] <- x  
     }
   } else {
     if(is.null(value)) {
